/*********************************************************
 * Copyright (C) 2008 VMware, Inc. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation version 2.1 and no later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the Lesser GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA.
 *
 *********************************************************/

#ifndef _GUESTINFOINT_H_
#define _GUESTINFOINT_H_

/**
 * @file guestInfoInt.h
 *
 * Declares internal functions of the guestInfo plugin.
 */

#define G_LOG_DOMAIN "guestinfo"
#include <glib.h>

#include "guestInfoLib.h"

extern int guestInfoPollInterval;

Bool
GuestInfo_PerfMon(struct GuestMemInfo *vmStats);

#endif /* _GUESTINFOINT_H_ */

